@@ -7,28 +7,35 @@ from torch.nn import functional as F
 from .identity import Identity
 
 __all__ = [
+    "ABN",
     "ACT_ELU",
     "ACT_HARD_SIGMOID",
     "ACT_HARD_SWISH",
     "ACT_LEAKY_RELU",
+    "ACT_MISH",
+    "ACT_MISH_NAIVE",
     "ACT_NONE",
     "ACT_RELU",
     "ACT_RELU6",
     "ACT_SELU",
     "ACT_SWISH",
-    "ACT_MISH",
-    "mish",
-    "swish",
-    "hard_sigmoid",
-    "hard_swish",
+    "ACT_SWISH_NAIVE",
+    "AGN",
     "HardSigmoid",
     "HardSwish",
+    "Mish",
+    "MishNaive",
     "Swish",
-    "instantiate_activation_block",
+    "SwishNaive",
     "get_activation_block",
+    "hard_sigmoid",
+    "hard_swish",
+    "instantiate_activation_block",
+    "mish",
+    "mish_naive",
     "sanitize_activation_name",
-    "ABN",
-    "AGN",
+    "swish",
+    "swish_naive",
 ]
 
 # Activation names
@@ -39,6 +46,7 @@ ACT_HARD_SIGMOID = "hard_sigmoid"
 ACT_HARD_SWISH = "hard_swish"
 ACT_LEAKY_RELU = "leaky_relu"
 ACT_MISH = "mish"
+ACT_MISH_NAIVE = "mish_naive"
 ACT_NONE = "none"
 ACT_PRELU = "prelu"
 ACT_RELU = "relu"
@@ -48,27 +56,49 @@ ACT_SWISH = "swish"
 ACT_SWISH_NAIVE = "swish_naive"
 
 
+# This version reduces memory overhead of Swish during training by
+# recomputing torch.sigmoid(x) in backward instead of saving it.
+@torch.jit.script
+def swish_jit_fwd(x):
+    return x.mul(torch.sigmoid(x))
+
+
+@torch.jit.script
+def swish_jit_bwd(x, grad_output):
+    x_sigmoid = torch.sigmoid(x)
+    return grad_output * (x_sigmoid * (1 + x * (1 - x_sigmoid)))
+
+
 class SwishFunction(torch.autograd.Function):
     """
     Memory efficient Swish implementation.
 
-    Credit: https://blog.ceshine.net/post/pytorch-memory-swish/
+    Credit:
+        https://blog.ceshine.net/post/pytorch-memory-swish/
+        https://github.com/rwightman/pytorch-image-models/blob/master/timm/models/layers/activations_jit.py
+
     """
 
     @staticmethod
-    def forward(ctx, i):
-        result = i * torch.sigmoid(i)
-        ctx.save_for_backward(i)
-        return result
+    def forward(ctx, x):
+        ctx.save_for_backward(x)
+        return swish_jit_fwd(x)
 
     @staticmethod
     def backward(ctx, grad_output):
-        i = ctx.saved_variables[0]
-        sigmoid_i = torch.sigmoid(i)
-        return grad_output * (sigmoid_i * (1 + i * (1 - sigmoid_i)))
+        x = ctx.saved_tensors[0]
+        return swish_jit_bwd(x, grad_output)
 
 
-def mish(input):
+def swish(x):
+    return SwishFunction.apply(x)
+
+
+def swish_naive(x):
+    return x * x.sigmoid()
+
+
+def mish_naive(input):
     """
     Apply the mish function element-wise:
     mish(x) = x * tanh(softplus(x)) = x * tanh(ln(1 + exp(x)))
@@ -78,6 +108,53 @@ def mish(input):
     return input * torch.tanh(F.softplus(input))
 
 
+class MishNaive(nn.Module):
+    def __init__(self, inplace=False):
+        super().__init__()
+
+    def forward(self, x):
+        return mish_naive(x)
+
+
+@torch.jit.script
+def mish_jit_fwd(x):
+    return x.mul(torch.tanh(F.softplus(x)))
+
+
+@torch.jit.script
+def mish_jit_bwd(x, grad_output):
+    x_sigmoid = torch.sigmoid(x)
+    x_tanh_sp = F.softplus(x).tanh()
+    return grad_output.mul(x_tanh_sp + x * x_sigmoid * (1 - x_tanh_sp * x_tanh_sp))
+
+
+class MishFunction(torch.autograd.Function):
+    """
+    Mish: A Self Regularized Non-Monotonic Neural Activation Function - https://arxiv.org/abs/1908.08681
+    A memory efficient, jit scripted variant of Mish
+    """
+
+    @staticmethod
+    def forward(ctx, x):
+        ctx.save_for_backward(x)
+        return mish_jit_fwd(x)
+
+    @staticmethod
+    def backward(ctx, grad_output):
+        x = ctx.saved_tensors[0]
+        return mish_jit_bwd(x, grad_output)
+
+
+def mish(x):
+    """
+    Apply the mish function element-wise:
+    mish(x) = x * tanh(softplus(x)) = x * tanh(ln(1 + exp(x)))
+    See additional documentation for mish class.
+    Credit: https://github.com/digantamisra98/Mish
+    """
+    return MishFunction.apply(x)
+
+
 class Mish(nn.Module):
     """
     Applies the mish function element-wise:
@@ -94,9 +171,10 @@ class Mish(nn.Module):
     Credit: https://github.com/digantamisra98/Mish
     """
 
-    def __init__(self):
+    def __init__(self, inplace=False):
         """
         Init method.
+        :param inplace: Not used, exists only for compatibility
         """
         super().__init__()
 
@@ -107,14 +185,6 @@ class Mish(nn.Module):
         return mish(input)
 
 
-def swish(x):
-    return SwishFunction.apply(x)
-
-
-def swish_naive(x):
-    return x * x.sigmoid()
-
-
 def hard_sigmoid(x, inplace=False):
     return F.relu6(x + 3, inplace) / 6
 
@@ -138,6 +208,9 @@ class SwishNaive(nn.Module):
 
 
 class Swish(nn.Module):
+    def __init__(self, inplace=False):
+        super(Swish, self).__init__()
+
     def forward(self, input_tensor):
         return swish(input_tensor)
 
@@ -161,6 +234,7 @@ def get_activation_block(activation_name: str):
         ACT_HARD_SWISH: HardSwish,
         ACT_LEAKY_RELU: nn.LeakyReLU,
         ACT_MISH: Mish,
+        ACT_MISH_NAIVE: MishNaive,
         ACT_NONE: Identity,
         ACT_RELU6: nn.ReLU6,
         ACT_RELU: nn.ReLU,
@@ -190,7 +264,7 @@ def sanitize_activation_name(activation_name: str) -> str:
     """
     Return reasonable activation name for initialization in `kaiming_uniform_` for hipster activations
     """
-    if activation_name in {ACT_MISH, ACT_SWISH, ACT_SWISH_NAIVE}:
+    if activation_name in {ACT_MISH, ACT_SWISH, ACT_SWISH_NAIVE, ACT_MISH_NAIVE}:
         return ACT_LEAKY_RELU
 
     return activation_name
