@@ -8,729 +8,570 @@
 import random
 
 left = [
-    'admiring',
-    'adoring',
-    'affectionate',
-    'agitated',
-    'amazing',
-    'angry',
-    'awesome',
-    'blissful',
-    'boring',
-    'brave',
-    'clever',
-    'cocky',
-    'compassionate',
-    'competent',
-    'condescending',
-    'confident',
-    'cranky',
-    'dazzling',
-    'determined',
-    'distracted',
-    'dreamy',
-    'eager',
-    'ecstatic',
-    'elastic',
-    'elated',
-    'elegant',
-    'eloquent',
-    'epic',
-    'fervent',
-    'festive',
-    'flamboyant',
-    'focused',
-    'friendly',
-    'frosty',
-    'gallant',
-    'gifted',
-    'goofy',
-    'gracious',
-    'happy',
-    'hardcore',
-    'heuristic',
-    'hopeful',
-    'hungry',
-    'infallible',
-    'inspiring',
-    'jolly',
-    'jovial',
-    'keen',
-    'kind',
-    'laughing',
-    'loving',
-    'lucid',
-    'mystifying',
-    'modest',
-    'musing',
-    'naughty',
-    'nervous',
-    'nifty',
-    'nostalgic',
-    'objective',
-    'optimistic',
-    'peaceful',
-    'pedantic',
-    'pensive',
-    'practical',
-    'priceless',
-    'quirky',
-    'quizzical',
-    'relaxed',
-    'reverent',
-    'romantic',
-    'sad',
-    'serene',
-    'sharp',
-    'silly',
-    'sleepy',
-    'stoic',
-    'stupefied',
-    'suspicious',
-    'tender',
-    'thirsty',
-    'trusting',
-    'unruffled',
-    'upbeat',
-    'vibrant',
-    'vigilant',
-    'vigorous',
-    'wizardly',
-    'wonderful',
-    'xenodochial',
-    'youthful',
-    'zealous',
-    'zen',
+    "admiring",
+    "adoring",
+    "affectionate",
+    "agitated",
+    "amazing",
+    "angry",
+    "awesome",
+    "blissful",
+    "boring",
+    "brave",
+    "clever",
+    "cocky",
+    "compassionate",
+    "competent",
+    "condescending",
+    "confident",
+    "cranky",
+    "dazzling",
+    "determined",
+    "distracted",
+    "dreamy",
+    "eager",
+    "ecstatic",
+    "elastic",
+    "elated",
+    "elegant",
+    "eloquent",
+    "epic",
+    "fervent",
+    "festive",
+    "flamboyant",
+    "focused",
+    "friendly",
+    "frosty",
+    "gallant",
+    "gifted",
+    "goofy",
+    "gracious",
+    "happy",
+    "hardcore",
+    "heuristic",
+    "hopeful",
+    "hungry",
+    "infallible",
+    "inspiring",
+    "jolly",
+    "jovial",
+    "keen",
+    "kind",
+    "laughing",
+    "loving",
+    "lucid",
+    "mystifying",
+    "modest",
+    "musing",
+    "naughty",
+    "nervous",
+    "nifty",
+    "nostalgic",
+    "objective",
+    "optimistic",
+    "peaceful",
+    "pedantic",
+    "pensive",
+    "practical",
+    "priceless",
+    "quirky",
+    "quizzical",
+    "relaxed",
+    "reverent",
+    "romantic",
+    "sad",
+    "serene",
+    "sharp",
+    "silly",
+    "sleepy",
+    "stoic",
+    "stupefied",
+    "suspicious",
+    "tender",
+    "thirsty",
+    "trusting",
+    "unruffled",
+    "upbeat",
+    "vibrant",
+    "vigilant",
+    "vigorous",
+    "wizardly",
+    "wonderful",
+    "xenodochial",
+    "youthful",
+    "zealous",
+    "zen",
 ]
 
 right = [
     # Muhammad ibn Jābir al-Ḥarrānī al-Battānī was a founding father of astronomy.
     # https://en.wikipedia.org/wiki/Mu%E1%B8%A5ammad_ibn_J%C4%81bir_al-%E1%B8%A4arr%C4%81n%C4%AB_al-Batt%C4%81n%C4%AB
-    'albattani',
-
+    "albattani",
     # Frances E. Allen, became the first female IBM Fellow in 1989. In 2006, she became the first female recipient of the ACM's Turing Award.
     # https://en.wikipedia.org/wiki/Frances_E._Allen
-    'allen',
-
+    "allen",
     # June Almeida - Scottish virologist who took the first pictures of the rubella virus - https://en.wikipedia.org/wiki/June_Almeida
-    'almeida',
-
+    "almeida",
     # Maria Gaetana Agnesi - Italian mathematician, philosopher, theologian and humanitarian.
     # She was the first woman to write a mathematics handbook and the first woman appointed as a
     # Mathematics Professor at a University. https://en.wikipedia.org/wiki/Maria_Gaetana_Agnesi
-    'agnesi',
-
+    "agnesi",
     # Archimedes was a physicist, engineer and mathematician who invented too many things to list them here.
     # https://en.wikipedia.org/wiki/Archimedes
-    'archimedes',
-
+    "archimedes",
     # Maria Ardinghelli - Italian translator, mathematician and physicist - https://en.wikipedia.org/wiki/Maria_Ardinghelli
-    'ardinghelli',
-
+    "ardinghelli",
     # Aryabhata - Ancient Indian mathematician-astronomer during 476-550 CE https://en.wikipedia.org/wiki/Aryabhata
-    'aryabhata',
-
+    "aryabhata",
     # Wanda Austin - Wanda Austin is the President and CEO of The Aerospace Corporation,
     # a leading architect for the US security space programs. https://en.wikipedia.org/wiki/Wanda_Austin
-    'austin',
-
+    "austin",
     # Charles Babbage invented the concept of a programmable computer. https://en.wikipedia.org/wiki/Charles_Babbage.
-    'babbage',
-
+    "babbage",
     # Stefan Banach - Polish mathematician, was one of the founders of modern functional analysis. https://en.wikipedia.org/wiki/Stefan_Banach
-    'banach',
-
+    "banach",
     # John Bardeen co-invented the transistor - https://en.wikipedia.org/wiki/John_Bardeen
-    'bardeen',
-
+    "bardeen",
     # Jean Bartik, born Betty Jean Jennings, was one of the original programmers for the ENIAC computer. https://en.wikipedia.org/wiki/Jean_Bartik
-    'bartik',
-
+    "bartik",
     # Laura Bassi, the world's first female professor https://en.wikipedia.org/wiki/Laura_Bassi
-    'bassi',
-
+    "bassi",
     # Hugh Beaver, British engineer, founder of the Guinness Book of World Records https://en.wikipedia.org/wiki/Hugh_Beaver
-    'beaver',
-
+    "beaver",
     # Alexander Graham Bell - an eminent Scottish-born scientist, inventor, engineer and innovator who is
     # credited with inventing the first practical telephone - https://en.wikipedia.org/wiki/Alexander_Graham_Bell
-    'bell',
-
+    "bell",
     # Karl Friedrich Benz - a German automobile engineer. Inventor of the first practical motorcar. https://en.wikipedia.org/wiki/Karl_Benz
-    'benz',
-
+    "benz",
     # Homi J Bhabha - was an Indian nuclear physicist, founding director, and professor of physics at the Tata Institute of Fundamental Research.
     # Colloquially known as 'father of Indian nuclear programme'- https://en.wikipedia.org/wiki/Homi_J._Bhabha
-    'bhabha',
-
+    "bhabha",
     # Bhaskara II - Ancient Indian mathematician-astronomer whose work on calculus predates Newton and Leibniz
     # by over half a millennium - https://en.wikipedia.org/wiki/Bh%C4%81skara_II#Calculus
-    'bhaskara',
-
+    "bhaskara",
     # Elizabeth Blackwell - American doctor and first American woman to receive a medical degree - https://en.wikipedia.org/wiki/Elizabeth_Blackwell
-    'blackwell',
-
+    "blackwell",
     # Niels Bohr is the father of quantum theory. https://en.wikipedia.org/wiki/Niels_Bohr.
-    'bohr',
-
+    "bohr",
     # Kathleen Booth, she's credited with writing the first assembly language. https://en.wikipedia.org/wiki/Kathleen_Booth
-    'booth',
-
+    "booth",
     # Anita Borg - Anita Borg was the founding director of the Institute for Women and Technology (IWT). https://en.wikipedia.org/wiki/Anita_Borg
-    'borg',
-
+    "borg",
     # Satyendra Nath Bose - He provided the foundation for Bose–Einstein statistics and the theory of the Bose–Einstein condensate.
     # https://en.wikipedia.org/wiki/Satyendra_Nath_Bose
-    'bose',
-
+    "bose",
     # Evelyn Boyd Granville - She was one of the first African-American woman to receive a Ph.D. in mathematics;
     # she earned it in 1949 from Yale University. https://en.wikipedia.org/wiki/Evelyn_Boyd_Granville
-    'boyd',
-
+    "boyd",
     # Brahmagupta - Ancient Indian mathematician during 598-670 CE who gave rules to compute
     # with zero - https://en.wikipedia.org/wiki/Brahmagupta#Zero
-    'brahmagupta',
-
+    "brahmagupta",
     # Walter Houser Brattain co-invented the transistor - https://en.wikipedia.org/wiki/Walter_Houser_Brattain
-    'brattain',
-
+    "brattain",
     # Emmett Brown invented time travel. https://en.wikipedia.org/wiki/Emmett_Brown (thanks Brian Goff)
-    'brown',
-
+    "brown",
     # Rachel Carson - American marine biologist and conservationist, her book Silent Spring and other
     # writings are credited with advancing the global environmental movement. https://en.wikipedia.org/wiki/Rachel_Carson
-    'carson',
-
+    "carson",
     # Subrahmanyan Chandrasekhar - Astrophysicist known for his mathematical theory on different stages and evolution in structures of the stars.
     # He has won nobel prize for physics - https://en.wikipedia.org/wiki/Subrahmanyan_Chandrasekhar
-    'chandrasekhar',
-
+    "chandrasekhar",
     # Claude Shannon - The father of information theory and founder of digital circuit design theory. (https://en.wikipedia.org/wiki/Claude_Shannon)
-    'shannon',
-
+    "shannon",
     # Joan Clarke - Bletchley Park code breaker during the Second World War who pioneered techniques
     # that remained top secret for decades. Also an accomplished numismatist https://en.wikipedia.org/wiki/Joan_Clarke
-    'clarke',
-
+    "clarke",
     # Jane Colden - American botanist widely considered the first female American botanist - https://en.wikipedia.org/wiki/Jane_Colden
-    'colden',
-
+    "colden",
     # Gerty Theresa Cori - American biochemist who became the third woman—and first American woman—to win a Nobel Prize in science,
     # and the first woman to be awarded the Nobel Prize in Physiology or Medicine.
     # Cori was born in Prague. https://en.wikipedia.org/wiki/Gerty_Cori
-    'cori',
-
+    "cori",
     # Seymour Roger Cray was an American electrical engineer and supercomputer architect who designed a series of computers
     # that were the fastest in the world for decades. https://en.wikipedia.org/wiki/Seymour_Cray
-    'cray',
-
+    "cray",
     # This entry reflects a husband and wife team who worked together:
     # Joan Curran was a Welsh scientist who developed radar and invented chaff, a radar countermeasure.
     # https://en.wikipedia.org/wiki/Joan_Curran
     # Samuel Curran was an Irish physicist who worked alongside his wife during WWII and invented the proximity fuse.
     # https://en.wikipedia.org/wiki/Samuel_Curran
-    'curran',
-
+    "curran",
     # Marie Curie discovered radioactivity. https://en.wikipedia.org/wiki/Marie_Curie.
-    'curie',
-
+    "curie",
     # Charles Darwin established the principles of natural evolution. https://en.wikipedia.org/wiki/Charles_Darwin.
-    'darwin',
-
+    "darwin",
     # Leonardo Da Vinci invented too many things to list here. https://en.wikipedia.org/wiki/Leonardo_da_Vinci.
-    'davinci',
-
+    "davinci",
     # Edsger Wybe Dijkstra was a Dutch computer scientist and mathematical scientist. https://en.wikipedia.org/wiki/Edsger_W._Dijkstra.
-    'dijkstra',
-
+    "dijkstra",
     # Donna Dubinsky - played an integral role in the development of personal digital assistants (PDAs)
     # serving as CEO of Palm, Inc. and co-founding Handspring. https://en.wikipedia.org/wiki/Donna_Dubinsky
-    'dubinsky',
-
+    "dubinsky",
     # Annie Easley - She was a leading member of the team which developed software for the Centaur rocket
     # stage and one of the first African-Americans in her field. https://en.wikipedia.org/wiki/Annie_Easley
-    'easley',
-
+    "easley",
     # Thomas Alva Edison, prolific inventor https://en.wikipedia.org/wiki/Thomas_Edison
-    'edison',
-
+    "edison",
     # Albert Einstein invented the general theory of relativity. https://en.wikipedia.org/wiki/Albert_Einstein
-    'einstein',
-
+    "einstein",
     # Gertrude Elion - American biochemist, pharmacologist and the 1988 recipient of
     # the Nobel Prize in Medicine - https://en.wikipedia.org/wiki/Gertrude_Elion
-    'elion',
-
+    "elion",
     # Douglas Engelbart gave the mother of all demos: https://en.wikipedia.org/wiki/Douglas_Engelbart
-    'engelbart',
-
+    "engelbart",
     # Euclid invented geometry. https://en.wikipedia.org/wiki/Euclid
-    'euclid',
-
+    "euclid",
     # Leonhard Euler invented large parts of modern mathematics. https://de.wikipedia.org/wiki/Leonhard_Euler
-    'euler',
-
+    "euler",
     # Pierre de Fermat pioneered several aspects of modern mathematics. https://en.wikipedia.org/wiki/Pierre_de_Fermat
-    'fermat',
-
+    "fermat",
     # Enrico Fermi invented the first nuclear reactor. https://en.wikipedia.org/wiki/Enrico_Fermi.
-    'fermi',
-
+    "fermi",
     # Richard Feynman was a key contributor to quantum mechanics and particle physics. https://en.wikipedia.org/wiki/Richard_Feynman
-    'feynman',
-
+    "feynman",
     # Benjamin Franklin is famous for his experiments in electricity and the invention of the lightning rod.
-    'franklin',
-
+    "franklin",
     # Galileo was a founding father of modern astronomy, and faced politics and obscurantism
     # to establish scientific truth.  https://en.wikipedia.org/wiki/Galileo_Galilei
-    'galileo',
-
+    "galileo",
     # William Henry 'Bill' Gates III is an American business magnate, philanthropist, investor,
     # computer programmer, and inventor. https://en.wikipedia.org/wiki/Bill_Gates
-    'gates',
-
+    "gates",
     # Adele Goldberg, was one of the designers and developers of the Smalltalk language.
     # https://en.wikipedia.org/wiki/Adele_Goldberg_(computer_scientist)
-    'goldberg',
-
+    "goldberg",
     # Adele Goldstine, born Adele Katz, wrote the complete technical description for the
     # first electronic digital computer, ENIAC. https://en.wikipedia.org/wiki/Adele_Goldstine
-    'goldstine',
-
+    "goldstine",
     # Shafi Goldwasser is a computer scientist known for creating theoretical foundations
     # of modern cryptography. Winner of 2012 ACM Turing Award. https://en.wikipedia.org/wiki/Shafi_Goldwasser
-    'goldwasser',
-
+    "goldwasser",
     # James Golick, all around gangster.
-    'golick',
-
+    "golick",
     # Jane Goodall - British primatologist, ethologist, and anthropologist who is considered
     # to be the world's foremost expert on chimpanzees - https://en.wikipedia.org/wiki/Jane_Goodall
-    'goodall',
-
+    "goodall",
     # Lois Haibt - American computer scientist, part of the team at IBM that developed FORTRAN - https://en.wikipedia.org/wiki/Lois_Haibt
-    'haibt',
-
+    "haibt",
     # Margaret Hamilton - Director of the Software Engineering Division of the MIT Instrumentation Laboratory,
     # which developed on-board flight software for the Apollo space program.
     # https://en.wikipedia.org/wiki/Margaret_Hamilton_(scientist)
-    'hamilton',
-
+    "hamilton",
     # Stephen Hawking pioneered the field of cosmology by combining general relativity and
     # quantum mechanics. https://en.wikipedia.org/wiki/Stephen_Hawking
-    'hawking',
-
+    "hawking",
     # Werner Heisenberg was a founding father of quantum mechanics. https://en.wikipedia.org/wiki/Werner_Heisenberg
-    'heisenberg',
-
+    "heisenberg",
     # Grete Hermann was a German philosopher noted for her philosophical work on the foundations of
     # quantum mechanics. https://en.wikipedia.org/wiki/Grete_Hermann
-    'hermann',
-
+    "hermann",
     # Jaroslav Heyrovský was the inventor of the polarographic method, father of the electroanalytical method, and recipient of the Nobel Prize in 1959.
     # His main field of work was polarography. https://en.wikipedia.org/wiki/Jaroslav_Heyrovsk%C3%BD
-    'heyrovsky',
-
+    "heyrovsky",
     # Dorothy Hodgkin was a British biochemist, credited with the development of protein crystallography.
     # She was awarded the Nobel Prize in Chemistry in 1964. https://en.wikipedia.org/wiki/Dorothy_Hodgkin
-    'hodgkin',
-
+    "hodgkin",
     # Erna Schneider Hoover revolutionized modern communication by inventing a computerized telephone switching method.
     # https://en.wikipedia.org/wiki/Erna_Schneider_Hoover
-    'hoover',
-
+    "hoover",
     # Grace Hopper developed the first compiler for a computer programming language and  is credited with popularizing
     # the term 'debugging' for fixing computer glitches. https://en.wikipedia.org/wiki/Grace_Hopper
-    'hopper',
-
+    "hopper",
     # Frances Hugle, she was an American scientist, engineer, and inventor who contributed to the understanding of semiconductors,
     # integrated circuitry, and the unique electrical principles of microscopic materials.
     # https://en.wikipedia.org/wiki/Frances_Hugle
-    'hugle',
-
+    "hugle",
     # Hypatia - Greek Alexandrine Neoplatonist philosopher in Egypt who was one of the earliest
     # mothers of mathematics - https://en.wikipedia.org/wiki/Hypatia
-    'hypatia',
-
+    "hypatia",
     # Mary Jackson, American mathematician and aerospace engineer who earned the highest title within
     # NASA's engineering department - https://en.wikipedia.org/wiki/Mary_Jackson_(engineer)
-    'jackson',
-
+    "jackson",
     # Yeong-Sil Jang was a Korean scientist and astronomer during the Joseon Dynasty;
     # he invented the first metal printing press and water gauge. https://en.wikipedia.org/wiki/Jang_Yeong-sil
-    'jang',
-
+    "jang",
     # Betty Jennings - one of the original programmers of the ENIAC.
     # https://en.wikipedia.org/wiki/ENIAC - https://en.wikipedia.org/wiki/Jean_Bartik
-    'jennings',
-
+    "jennings",
     # Mary Lou Jepsen, was the founder and chief technology officer of One Laptop Per Child (OLPC), and the founder of Pixel Qi.
     # https://en.wikipedia.org/wiki/Mary_Lou_Jepsen
-    'jepsen',
-
+    "jepsen",
     # Katherine Coleman Goble Johnson - American physicist and mathematician contributed to the NASA.
     # https://en.wikipedia.org/wiki/Katherine_Johnson
-    'johnson',
-
+    "johnson",
     # Irène Joliot-Curie - French scientist who was awarded the Nobel Prize for Chemistry in 1935.
     # Daughter of Marie and Pierre Curie. https://en.wikipedia.org/wiki/Ir%C3%A8ne_Joliot-Curie
-    'joliot',
-
+    "joliot",
     # Karen Spärck Jones came up with the concept of inverse document frequency,
     # which is used in most search engines today. https://en.wikipedia.org/wiki/Karen_Sp%C3%A4rck_Jones
-    'jones',
-
+    "jones",
     # A. P. J. Abdul Kalam - is an Indian scientist aka Missile Man of India for his work on the development of
     # ballistic missile and launch vehicle technology - https://en.wikipedia.org/wiki/A._P._J._Abdul_Kalam
-    'kalam',
-
+    "kalam",
     # Susan Kare, created the icons and many of the interface elements for the original Apple Macintosh in the 1980s,
     # and was an original employee of NeXT, working as the Creative Director.
     # https://en.wikipedia.org/wiki/Susan_Kare
-    'kare',
-
+    "kare",
     # Mary Kenneth Keller, Sister Mary Kenneth Keller became the first American woman to earn a PhD in Computer Science in 1965.
     # https://en.wikipedia.org/wiki/Mary_Kenneth_Keller
-    'keller',
-
+    "keller",
     # Johannes Kepler, German astronomer known for his three laws of planetary motion -
     # https://en.wikipedia.org/wiki/Johannes_Kepler
-    'kepler',
-
+    "kepler",
     # Har Gobind Khorana - Indian-American biochemist who shared the 1968 Nobel Prize for Physiology -
     # https://en.wikipedia.org/wiki/Har_Gobind_Khorana
-    'khorana',
-
+    "khorana",
     # Jack Kilby invented silicone integrated circuits and gave Silicon Valley its name. -
     # https://en.wikipedia.org/wiki/Jack_Kilby
-    'kilby',
-
+    "kilby",
     # Maria Kirch - German astronomer and first woman to discover a comet -
     # https://en.wikipedia.org/wiki/Maria_Margarethe_Kirch
-    'kirch',
-
+    "kirch",
     # Donald Knuth - American computer scientist, author of 'The Art of Computer Programming' and creator of the TeX typesetting system.
     # https://en.wikipedia.org/wiki/Donald_Knuth
-    'knuth',
-
+    "knuth",
     # Sophie Kowalevski - Russian mathematician responsible for important original contributions to analysis,
     # differential equations and mechanics -
     # https://en.wikipedia.org/wiki/Sofia_Kovalevskaya
-    'kowalevski',
-
+    "kowalevski",
     # Marie-Jeanne de Lalande - French astronomer, mathematician and cataloguer of stars -
     # https://en.wikipedia.org/wiki/Marie-Jeanne_de_Lalande
-    'lalande',
-
+    "lalande",
     # Hedy Lamarr - Actress and inventor. The principles of her work are now incorporated into modern Wi-Fi, CDMA and Bluetooth technology.
     # https://en.wikipedia.org/wiki/Hedy_Lamarr
-    'lamarr',
-
+    "lamarr",
     # Leslie B. Lamport - American computer scientist. Lamport is best known for his seminal work in distributed systems and was the winner of the 2013 Turing Award.
     # https://en.wikipedia.org/wiki/Leslie_Lamport
-    'lamport',
-
+    "lamport",
     # Mary Leakey - British paleoanthropologist who discovered the first fossilized Proconsul skull -
     # https://en.wikipedia.org/wiki/Mary_Leakey
-    'leakey',
-
+    "leakey",
     # Henrietta Swan Leavitt - she was an American astronomer who discovered the relation between the luminosity and the period of Cepheid variable stars.
     # https://en.wikipedia.org/wiki/Henrietta_Swan_Leavitt
-    'leavitt',
-
+    "leavitt",
     # Daniel Lewin -  Mathematician, Akamai co-founder, soldier, 9/11 victim-- Developed optimization techniques for routing traffic on the internet.
     # Died attempting to stop the 9-11 hijackers.
     # https://en.wikipedia.org/wiki/Daniel_Lewin
-    'lewin',
-
+    "lewin",
     # Ruth Lichterman - one of the original programmers of the ENIAC. https://en.wikipedia.org/wiki/ENIAC - https://en.wikipedia.org/wiki/Ruth_Teitelbaum
-    'lichterman',
-
+    "lichterman",
     # Barbara Liskov - co-developed the Liskov substitution principle. Liskov was also the winner of the Turing Prize in 2008. -
     # https://en.wikipedia.org/wiki/Barbara_Liskov
-    'liskov',
-
+    "liskov",
     # Ada Lovelace invented the first algorithm. https://en.wikipedia.org/wiki/Ada_Lovelace (thanks James Turnbull)
-    'lovelace',
-
+    "lovelace",
     # Auguste and Louis Lumière - the first filmmakers in history - https://en.wikipedia.org/wiki/Auguste_and_Louis_Lumi%C3%A8re
-    'lumiere',
-
+    "lumiere",
     # Mahavira - Ancient Indian mathematician during 9th century AD who discovered basic algebraic identities -
     # https://en.wikipedia.org/wiki/Mah%C4%81v%C4%ABra_(mathematician)
-    'mahavira',
-
+    "mahavira",
     # Maria Mayer - American theoretical physicist and Nobel laureate in Physics for proposing the nuclear
     # shell model of the atomic nucleus - https://en.wikipedia.org/wiki/Maria_Mayer
-    'mayer',
-
+    "mayer",
     # John McCarthy invented LISP: https://en.wikipedia.org/wiki/John_McCarthy_(computer_scientist)
-    'mccarthy',
-
+    "mccarthy",
     # Barbara McClintock - a distinguished American cytogeneticist, 1983 Nobel Laureate in Physiology or Medicine for discovering transposons.
     # https://en.wikipedia.org/wiki/Barbara_McClintock
-    'mcclintock',
-
+    "mcclintock",
     # Malcolm McLean invented the modern shipping container: https://en.wikipedia.org/wiki/Malcom_McLean
-    'mclean',
-
+    "mclean",
     # Kay McNulty - one of the original programmers of the ENIAC. https://en.wikipedia.org/wiki/ENIAC -
     # https://en.wikipedia.org/wiki/Kathleen_Antonelli
-    'mcnulty',
-
+    "mcnulty",
     # Lise Meitner - Austrian/Swedish physicist who was involved in the discovery of nuclear fission.
     # The element meitnerium is named after her - https://en.wikipedia.org/wiki/Lise_Meitner
-    'meitner',
-
+    "meitner",
     # Carla Meninsky, was the game designer and programmer for Atari 2600 games Dodge 'Em and Warlords.
     # https://en.wikipedia.org/wiki/Carla_Meninsky
-    'meninsky',
-
+    "meninsky",
     # Johanna Mestorf - German prehistoric archaeologist and first female museum director in Germany -
     # https://en.wikipedia.org/wiki/Johanna_Mestorf
-    'mestorf',
-
+    "mestorf",
     # Marvin Minsky - Pioneer in Artificial Intelligence, co-founder of the MIT's AI Lab, won the Turing Award in 1969.
     # https://en.wikipedia.org/wiki/Marvin_Minsky
-    'minsky',
-
+    "minsky",
     # Maryam Mirzakhani - an Iranian mathematician and the first woman to win the Fields Medal.
     # https://en.wikipedia.org/wiki/Maryam_Mirzakhani
-    'mirzakhani',
-
+    "mirzakhani",
     # Samuel Morse - contributed to the invention of a single-wire telegraph system based on
     # European telegraphs and was a co-developer of the Morse code -
     # https://en.wikipedia.org/wiki/Samuel_Morse
-    'morse',
-
+    "morse",
     # Ian Murdock - founder of the Debian project - https://en.wikipedia.org/wiki/Ian_Murdock
-    'murdock',
-
+    "murdock",
     # John von Neumann - todays computer architectures are based on the von Neumann architecture.
     # https://en.wikipedia.org/wiki/Von_Neumann_architecture
-    'neumann',
-
+    "neumann",
     # Isaac Newton invented classic mechanics and modern optics. https://en.wikipedia.org/wiki/Isaac_Newton
-    'newton',
-
+    "newton",
     # Florence Nightingale, more prominently known as a nurse, was also the first female member of the
     # Royal Statistical Society and a pioneer in statistical graphics
     # https://en.wikipedia.org/wiki/Florence_Nightingale#Statistics_and_sanitary_reform
-    'nightingale',
-
+    "nightingale",
     # Alfred Nobel - a Swedish chemist, engineer, innovator, and armaments manufacturer (inventor of dynamite) -
     # https://en.wikipedia.org/wiki/Alfred_Nobel
-    'nobel',
-
+    "nobel",
     # Emmy Noether, German mathematician. Noether's Theorem is named after her. https://en.wikipedia.org/wiki/Emmy_Noether
-    'noether',
-
+    "noether",
     # Poppy Northcutt. Poppy Northcutt was the first woman to work as part of NASA’s Mission Control.
     # http://www.businessinsider.com/poppy-northcutt-helped-apollo-astronauts-2014-12?op=1
-    'northcutt',
-
+    "northcutt",
     # Robert Noyce invented silicone integrated circuits and gave Silicon Valley its name. -
     # https://en.wikipedia.org/wiki/Robert_Noyce
-    'noyce',
-
+    "noyce",
     # Panini - Ancient Indian linguist and grammarian from 4th century CE who worked on the world's first formal system -
     # https://en.wikipedia.org/wiki/P%C4%81%E1%B9%87ini#Comparison_with_modern_formal_systems
-    'panini',
-
+    "panini",
     # Ambroise Pare invented modern surgery. https://en.wikipedia.org/wiki/Ambroise_Par%C3%A9
-    'pare',
-
+    "pare",
     # Louis Pasteur discovered vaccination, fermentation and pasteurization. https://en.wikipedia.org/wiki/Louis_Pasteur.
-    'pasteur',
-
+    "pasteur",
     # Cecilia Payne-Gaposchkin was an astronomer and astrophysicist who, in 1925, proposed
     # in her Ph.D. thesis an explanation for the composition of stars in terms of the relative abundances of hydrogen and helium.
     # https://en.wikipedia.org/wiki/Cecilia_Payne-Gaposchkin
-    'payne',
-
+    "payne",
     # Radia Perlman is a software designer and network engineer and most famous for her
     # invention of the spanning-tree protocol (STP). https://en.wikipedia.org/wiki/Radia_Perlman
-    'perlman',
-
+    "perlman",
     # Rob Pike was a key contributor to Unix, Plan 9, the X graphic system, utf-8, and the Go programming language.
     # https://en.wikipedia.org/wiki/Rob_Pike
-    'pike',
-
+    "pike",
     # Henri Poincaré made fundamental contributions in several fields of mathematics.
     # https://en.wikipedia.org/wiki/Henri_Poincar%C3%A9
-    'poincare',
-
+    "poincare",
     # Laura Poitras is a director and producer whose work, made possible by open source crypto tools, advances
     # the causes of truth and freedom of information by reporting disclosures by
     # whistleblowers such as Edward Snowden. https://en.wikipedia.org/wiki/Laura_Poitras
-    'poitras',
-
+    "poitras",
     # Claudius Ptolemy - a Greco-Egyptian writer of Alexandria, known as a mathematician, astronomer, geographer, astrologer,
     # and poet of a single epigram in the Greek Anthology - https://en.wikipedia.org/wiki/Ptolemy
-    'ptolemy',
-
+    "ptolemy",
     # C. V. Raman - Indian physicist who won the Nobel Prize in 1930 for proposing the Raman effect. -
     # https://en.wikipedia.org/wiki/C._V._Raman
-    'raman',
-
+    "raman",
     # Srinivasa Ramanujan - Indian mathematician and autodidact who made extraordinary contributions to
     # mathematical analysis, number theory, infinite series, and continued fractions.
     # https://en.wikipedia.org/wiki/Srinivasa_Ramanujan
-    'ramanujan',
-
+    "ramanujan",
     # Sally Kristen Ride was an American physicist and astronaut. She was the first American woman in space,
     # and the youngest American astronaut. https://en.wikipedia.org/wiki/Sally_Ride
-    'ride',
-
+    "ride",
     # Rita Levi-Montalcini - Won Nobel Prize in Physiology or Medicine jointly with colleague Stanley Cohen
     # for the discovery of nerve growth factor (https://en.wikipedia.org/wiki/Rita_Levi-Montalcini)
-    'montalcini',
-
+    "montalcini",
     # Dennis Ritchie - co-creator of UNIX and the C programming language. -
     # https://en.wikipedia.org/wiki/Dennis_Ritchie
-    'ritchie',
-
+    "ritchie",
     # Wilhelm Conrad Röntgen - German physicist who was awarded the first Nobel Prize in Physics in 1901
     # for the discovery of X-rays (Röntgen rays). https://en.wikipedia.org/wiki/Wilhelm_R%C3%B6ntgen
-    'roentgen',
-
+    "roentgen",
     # Rosalind Franklin - British biophysicist and X-ray crystallographer whose research was critical to
     # the understanding of DNA - https://en.wikipedia.org/wiki/Rosalind_Franklin
-    'rosalind',
-
+    "rosalind",
     # Meghnad Saha - Indian astrophysicist best known for his development of the Saha equation, used to
     # describe chemical and physical conditions in stars - https://en.wikipedia.org/wiki/Meghnad_Saha
-    'saha',
-
+    "saha",
     # Jean E. Sammet developed FORMAC, the first widely used computer language for symbolic manipulation
     # of mathematical formulas. https://en.wikipedia.org/wiki/Jean_E._Sammet
-    'sammet',
-
+    "sammet",
     # Carol Shaw - Originally an Atari employee, Carol Shaw is said to be the first female video game designer.
     # https://en.wikipedia.org/wiki/Carol_Shaw_(video_game_designer)
-    'shaw',
-
+    "shaw",
     # Dame Stephanie 'Steve' Shirley - Founded a software company in 1962 employing women working from home.
     # https://en.wikipedia.org/wiki/Steve_Shirley
-    'shirley',
-
+    "shirley",
     # William Shockley co-invented the transistor - https://en.wikipedia.org/wiki/William_Shockley
-    'shockley',
-
+    "shockley",
     # Françoise Barré-Sinoussi - French virologist and Nobel Prize Laureate in Physiology or Medicine;
     # her work was fundamental in identifying HIV as the cause of AIDS.
     # https://en.wikipedia.org/wiki/Fran%C3%A7oise_Barr%C3%A9-Sinoussi
-    'sinoussi',
-
+    "sinoussi",
     # Betty Snyder - one of the original programmers of the ENIAC. https://en.wikipedia.org/wiki/ENIAC -
     # https://en.wikipedia.org/wiki/Betty_Holberton
-    'snyder',
-
+    "snyder",
     # Frances Spence - one of the original programmers of the ENIAC. https://en.wikipedia.org/wiki/ENIAC -
     # https://en.wikipedia.org/wiki/Frances_Spence
-    'spence',
-
+    "spence",
     # Richard Matthew Stallman - the founder of the Free Software movement, the GNU project, the Free Software Foundation,
     # and the League for Programming Freedom.
     # He also invented the concept of copyleft to protect the ideals of this movement, and enshrined
     # this concept in the widely-used GPL (General Public License) for software.
     # https://en.wikiquote.org/wiki/Richard_Stallman
-    'stallman',
-
+    "stallman",
     # Michael Stonebraker is a database research pioneer and architect of Ingres, Postgres, VoltDB and SciDB.
     # Winner of 2014 ACM Turing Award. https://en.wikipedia.org/wiki/Michael_Stonebraker
-    'stonebraker',
-
+    "stonebraker",
     # Janese Swanson (with others) developed the first of the Carmen Sandiego games.
     # She went on to found Girl Tech. https://en.wikipedia.org/wiki/Janese_Swanson
-    'swanson',
-
+    "swanson",
     # Aaron Swartz was influential in creating RSS, Markdown, Creative Commons, Reddit,
     # and much of the internet as we know it today. He was devoted to freedom of information on the web.
     # https://en.wikiquote.org/wiki/Aaron_Swartz
-    'swartz',
-
+    "swartz",
     # Bertha Swirles was a theoretical physicist who made a number of contributions to early quantum theory.
     # https://en.wikipedia.org/wiki/Bertha_Swirles
-    'swirles',
-
+    "swirles",
     # Nikola Tesla invented the AC electric system and every gadget ever used by a James Bond villain.
     # https://en.wikipedia.org/wiki/Nikola_Tesla
-    'tesla',
-
+    "tesla",
     # Ken Thompson - co-creator of UNIX and the C programming language -
     # https://en.wikipedia.org/wiki/Ken_Thompson
-    'thompson',
-
+    "thompson",
     # Linus Torvalds invented Linux and Git.
     # https://en.wikipedia.org/wiki/Linus_Torvalds
-    'torvalds',
-
+    "torvalds",
     # Alan Turing was a founding father of computer science.
     # https://en.wikipedia.org/wiki/Alan_Turing.
-    'turing',
-
+    "turing",
     # Varahamihira - Ancient Indian mathematician who discovered trigonometric formulae during
     # 505-587 CE - https://en.wikipedia.org/wiki/Var%C4%81hamihira#Contributions
-    'varahamihira',
-
+    "varahamihira",
     # Sir Mokshagundam Visvesvaraya - is a notable Indian engineer.
     # He is a recipient of the Indian Republic's highest honour,
     # the Bharat Ratna, in 1955. On his birthday,
     # 15 September is celebrated as Engineer's Day in India in his memory - https://en.wikipedia.org/wiki/Visvesvaraya
-    'visvesvaraya',
-
+    "visvesvaraya",
     # Christiane Nüsslein-Volhard - German biologist, won Nobel Prize in Physiology or Medicine in 1995
     # for research on the genetic control of embryonic development.
     # https://en.wikipedia.org/wiki/Christiane_N%C3%BCsslein-Volhard
-    'volhard',
-
+    "volhard",
     # Marlyn Wescoff - one of the original programmers of the ENIAC.
     # https://en.wikipedia.org/wiki/ENIAC - https://en.wikipedia.org/wiki/Marlyn_Meltzer
-    'wescoff',
-
+    "wescoff",
     # Andrew Wiles - Notable British mathematician who proved the enigmatic Fermat's Last Theorem -
     # https://en.wikipedia.org/wiki/Andrew_Wiles
-    'wiles',
-
+    "wiles",
     # Roberta Williams, did pioneering work in graphical adventure games for personal computers,
     # particularly the King's Quest series. https://en.wikipedia.org/wiki/Roberta_Williams
-    'williams',
-
+    "williams",
     # Sophie Wilson designed the first Acorn Micro-Computer and the instruction set for ARM processors. https://en.wikipedia.org/wiki/Sophie_Wilson
-    'wilson',
-
+    "wilson",
     # Jeannette Wing - co-developed the Liskov substitution principle. - https://en.wikipedia.org/wiki/Jeannette_Wing
-    'wing',
-
+    "wing",
     # Steve Wozniak invented the Apple I and Apple II.
     # https://en.wikipedia.org/wiki/Steve_Wozniak
-    'wozniak',
-
+    "wozniak",
     # The Wright brothers, Orville and Wilbur - credited with inventing and building
     # the world's first successful airplane and making the first controlled, powered and sustained heavier-than-air human flight -
     # https://en.wikipedia.org/wiki/Wright_brothers
-    'wright',
-
+    "wright",
     # Rosalyn Sussman Yalow - Rosalyn Sussman Yalow was an American medical physicist,
     # and a co-winner of the 1977 Nobel Prize in Physiology or Medicine for development of the radioimmunoassay technique.
     # https://en.wikipedia.org/wiki/Rosalyn_Sussman_Yalow
-    'yalow',
-
+    "yalow",
     # Ada Yonath - an Israeli crystallographer, the first woman from the Middle East to win a Nobel prize in the sciences. https://en.wikipedia.org/wiki/Ada_Yonath
-    'yonath',
+    "yonath",
 ]
 
 
-def get_random_name(sep='_'):
+def get_random_name(sep="_"):
     r = random.SystemRandom()
     while 1:
-        name = '%s%s%s' % (r.choice(left), sep, r.choice(right))
-        if name == 'boring' + sep + 'wozniak':  # Steve Wozniak is not boring
+        name = "%s%s%s" % (r.choice(left), sep, r.choice(right))
+        if name == "boring" + sep + "wozniak":  # Steve Wozniak is not boring
             continue
         return name
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     print(get_random_name())
